﻿using System;
using System.IO;
using System.Text;
using System.Data;
using System.Configuration;
using WebReports.Api;
using WebReports.Api.Common;
using SqlUtils;
using Newtonsoft.Json;

namespace ExagoExtensibility
{

    public enum ScheduleJobStatus : int {
        Ready = 0,          // job is ready for execution
        Running = 1,        // job is currently running
        Completed = 2,      // job exection has completed and job will be rescheduled
        Suspended = 3,      // job has been suspended and will not be executed again
        Deleted = 4,        // job has been deleted will be removed on next flush
        Abended = 5,        // job abended on last execution will not run again
        UserAbort = 6,      // job is running and user has requested to delete it
        Transmitting = 7,   // job is completed and waiting for data to be transmitted to client for synchronous execution
        Removed = 8,        // job should be removed if it hasn't already
        Immediate = 9		// job should be executed as soon as a slot is available
    };
    
    /// <summary>
    /// Class that reads specific database table name appSettings configurations from the executing
    /// program's web.config and caches them in memory for fast reference.
    /// </summary>
    public static class DbTables
    {
        public static string SchedulerJobs { get; set; }

        static DbTables()
        {
             SchedulerJobs = ConfigurationManager.AppSettings["tnSchedulerJobs"];
        }
    }

    /// <summary>
    /// This static class contains a number of unrelated methods that are used in various disjoint places in the system.
    /// </summary>
    public static class Utilities
	{
        /**
		 * Read a file to string, line by line, and return the string
		 * @param fileName is the file to read
		 * @return the file contents as a string 
		 */
        public static string readFileToString(string fileName)
		{
			string str;
			StringBuilder sb = new StringBuilder();            // string builders can be easily changed, whereas strings are immutable and inefficient when concatenating
			try
			{
				using (StreamReader sr = File.OpenText(fileName))
				{
					str = sr.ReadLine();                      // read first line
					while (str != null)                       // if we're not at the end of the file, keep going
					{
						sb.Append(str + System.Environment.NewLine);  // concatenate new line to existing string buffer; tack on a environment-specific carriage return
						str = sr.ReadLine();                  // read next line
					}
				}
			}
			catch (Exception ex)
			{
				sb.Append("Could not read the source code file because: ");
				sb.Append(ex.Message);
			}
			return sb.ToString();
		}


        /**
        * Log text to the Exago Logs. Configured through log4Net settings.
        * Additional information here https://support.exagoinc.com/hc/en-us/articles/215058008
        * @param logText is the text to write to the log
        * @param writeLog is a boolean that determines if the logging method should continue
        */
        public static void Log(string logText, bool writeLog)
        {
            Logger logger = WebReports.Api.Common.Log.GetLogger();
            try
            {
                if (writeLog)
                {
                    logger.Info(logText);
                }
            }
            catch { }
        }        
    }
}

